#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4
visibility:           public
id:                   pandoc-lua-engine-0.4-9j6F4znmxWGHhfBrL605t7
key:                  pandoc-lua-engine-0.4-9j6F4znmxWGHhfBrL605t7
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  b7148b04aaf3b4b95cc18d05f7b51d6e
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4-9j6F4znmxWGHhfBrL605t7
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-46rCQ7zA3MgFfTbfrgWraX
    containers-0.6.7 crypton-1.0.4-3mMbBQHl0K4EgHAKLusoNW
    data-default-0.7.1.3-CRQVneoi5B7He0Tx6HSYSU
    doclayout-0.5.0.1-I4N2BziaX6w4Je0lnOtrUI
    doctemplates-0.11.0.1-2sWGZckRwCV3STeHrvFtcV exceptions-0.10.7
    hslua-2.3.1-3l1ydHfAyEG8duhhFOhYhG
    hslua-module-doclayout-1.2.0-2ulXJGo9cQc709SMUQvE4R
    hslua-module-path-1.1.1-JeeyDOjaDMPK7JgrqNOsHH
    hslua-module-system-1.1.2-nZmU5szcXrBqqvvO5M0Rw
    hslua-module-text-1.1.1-AWhgbZdVJcVGy0ScIZ9XJh
    hslua-module-version-1.1.1-O37Es0Kmep4lmqSymC1jG
    hslua-module-zip-1.1.3-5u7meN94f0WIwBaqI6AC7i
    hslua-repl-0.1.2-BDhsGJ5rM4WIeSAbJVb3Li
    lpeg-1.1.0-FE3IY0ukVeHFwblTrqchNo mtl-2.3.1
    pandoc-3.6-6m1IYYZohYg3K7Z4Mkk8uD
    pandoc-lua-marshal-0.3.0-GfRVsK48zNv4RHBHAHMPB6
    pandoc-types-1.23.1.1-8Liik9ap3oiIlMB4i0obm2 parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

